@@ -57,10 +57,6 @@ class NetworkUtils(object):
     _ACL_ACTION_DENY = 2
     _ACL_ACTION_METER = 3
 
-    _METRIC_ENABLED = 2
-    _NET_IN_METRIC_NAME = 'Filtered Incoming Network Traffic'
-    _NET_OUT_METRIC_NAME = 'Filtered Outgoing Network Traffic'
-
     _ACL_APPLICABILITY_LOCAL = 1
     _ACL_APPLICABILITY_REMOTE = 2
 
@@ -318,22 +314,6 @@ class NetworkUtils(object):
                         acl_dir, acl_type, self._ACL_ACTION_METER)
                     self._jobutils.add_virt_feature(acl, port)
 
-    def enable_control_metrics(self, switch_port_name):
-        port, found = self._get_switch_port_allocation(switch_port_name, False)
-        if not found:
-            return
-
-        metric_svc = self._conn.Msvm_MetricService()[0]
-        metric_names = [self._NET_IN_METRIC_NAME, self._NET_OUT_METRIC_NAME]
-
-        for metric_name in metric_names:
-            metric_def = self._conn.CIM_BaseMetricDefinition(Name=metric_name)
-            if metric_def:
-                metric_svc.ControlMetrics(
-                    Subject=port.path_(),
-                    Definition=metric_def[0].path_(),
-                    MetricCollectionEnabled=self._METRIC_ENABLED)
-
     def can_enable_control_metrics(self, switch_port_name):
         port, found = self._get_switch_port_allocation(switch_port_name, False)
         if not found:
